@@ -32,7 +32,7 @@ static bool pciDetectDriver(FFstrbuf* result, FFstrbuf* pciDir, FFstrbuf* buffer
     uint32_t pciDirLength = pciDir->length;
     ffStrbufAppendS(pciDir, "/driver");
     char pathBuf[PATH_MAX];
-    ssize_t resultLength = readlink(pciDir->chars, pathBuf, sizeof(pathBuf));
+    ssize_t resultLength = readlink(pciDir->chars, pathBuf, ARRAY_SIZE(pathBuf));
     if(resultLength <= 0) return false;
 
     const char* slash = memrchr(pathBuf, '/', (size_t) resultLength);
@@ -78,7 +78,7 @@ static bool pciDetectDriver(FFstrbuf* result, FFstrbuf* pciDir, FFstrbuf* buffer
     return true;
 }
 
-static const char* drmFindRenderFromCard(const char* drmCardKey, FFstrbuf* result)
+FF_MAYBE_UNUSED static const char* drmFindRenderFromCard(const char* drmCardKey, FFstrbuf* result)
 {
     char path[PATH_MAX];
     sprintf(path, "/sys/class/drm/%s/device/drm", drmCardKey);
@@ -395,6 +395,7 @@ static const char* drmDetectIntelSpecific(FFGPUResult* gpu, const char* drmKey,
     }
     return NULL;
     #else
+    FF_UNUSED(gpu, drmKey, buffer);
     return "Fastfetch is not compiled with drm support";
     #endif
 }
@@ -414,7 +415,7 @@ static const char* detectPci(const FFGPUOptions* options, FFlist* gpus, FFstrbuf
     const char* pPciPath = NULL;
     if (drmKey)
     {
-        ssize_t pathLength = readlink(deviceDir->chars, pciPath, sizeof(pciPath) - 1);
+        ssize_t pathLength = readlink(deviceDir->chars, pciPath, ARRAY_SIZE(pciPath) - 1);
         if (pathLength <= 0)
             return "Unable to get PCI device path";
         pciPath[pathLength] = '\0';
@@ -459,8 +460,7 @@ static const char* detectPci(const FFGPUOptions* options, FFlist* gpus, FFstrbuf
             {
                 if (ffStrStartsWith(entry->d_name, "card"))
                 {
-                    strncpy(drmKeyBuffer, entry->d_name, sizeof(drmKeyBuffer) - 1);
-                    drmKeyBuffer[sizeof(drmKeyBuffer) - 1] = '\0';
+                    ffStrCopyN(drmKeyBuffer, entry->d_name, ARRAY_SIZE(drmKeyBuffer));
                     drmKey = drmKeyBuffer;
                     break;
                 }
@@ -493,7 +493,7 @@ static const char* detectPci(const FFGPUOptions* options, FFlist* gpus, FFstrbuf
                 if (pend != buffer->chars)
                 {
                     char query[32];
-                    snprintf(query, sizeof(query), "%X,\t%X,", (unsigned) deviceId, (unsigned) revision);
+                    snprintf(query, ARRAY_SIZE(query), "%X,\t%X,", (unsigned) deviceId, (unsigned) revision);
                     #ifdef FF_CUSTOM_AMDGPU_IDS_PATH
                     ffParsePropFile(FF_STR(FF_CUSTOM_AMDGPU_IDS_PATH), query, &gpu->name);
                     #else
@@ -625,7 +625,7 @@ FF_MAYBE_UNUSED static const char* drmDetectAsahiSpecific(FFGPUResult* gpu, cons
 static const char* detectOf(FFlist* gpus, FFstrbuf* buffer, FFstrbuf* drmDir, const char* drmKey)
 {
     char compatible[256]; // vendor,model-name
-    if (sscanf(buffer->chars + strlen("of:"), "NgpuT%*[^C]C%256[^C]", compatible) != 1)
+    if (sscanf(buffer->chars + strlen("of:"), "NgpuT%*[^C]C%255[^C]", compatible) != 1)
         return "Failed to parse of modalias or not a GPU device";
 
     char* name = strchr(compatible, ',');
@@ -657,11 +657,19 @@ static const char* detectOf(FFlist* gpus, FFstrbuf* buffer, FFstrbuf* drmDir, co
     #endif
 
     if (!gpu->name.length)
+    {
         ffStrbufSetS(&gpu->name, name ? name : compatible);
+        ffStrbufTrimRightSpace(&gpu->name);
+    }
     if (!gpu->vendor.length && name)
     {
-        compatible[0] = (char) toupper(compatible[0]);
-        ffStrbufSetS(&gpu->vendor, compatible);
+        if (ffStrEquals(compatible, "brcm"))
+            ffStrbufSetStatic(&gpu->vendor, "Broadcom"); // Raspberry Pi
+        else
+        {
+            ffStrbufSetS(&gpu->vendor, compatible);
+            gpu->vendor.chars[0] = (char) toupper(compatible[0]);
+        }
     }
 
     return NULL;
