@@ -1,8 +1,5 @@
 #pragma once
 
-#ifndef FASTFETCH_INCLUDED_FFSTRBUF
-#define FASTFETCH_INCLUDED_FFSTRBUF
-
 #include "FFcheckmacros.h"
 
 #include <stdint.h>
@@ -382,7 +379,7 @@ static inline FF_C_NODISCARD uint32_t ffStrbufFirstIndexS(const FFstrbuf* strbuf
 static inline FF_C_NODISCARD uint32_t ffStrbufLastIndexC(const FFstrbuf* strbuf, char c)
 {
     if(strbuf->length == 0)
-        return strbuf->length;
+        return 0;
 
     return ffStrbufPreviousIndexC(strbuf, strbuf->length - 1, c);
 }
@@ -491,5 +488,3 @@ static inline void ffStrbufTrim(FFstrbuf* strbuf, char c)
 }
 
 #define FF_STRBUF_AUTO_DESTROY FFstrbuf __attribute__((__cleanup__(ffStrbufDestroy)))
-
-#endif
